/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ratis.thirdparty.demo;

import org.apache.ratis.thirdparty.com.google.common.collect.Lists;

import java.util.List;

public class GrpcSslConfig {
  // TODO: allow configure cipher suites
  private final List<String> tlsCipherSuitesWithEncryption = Lists.newArrayList(
      "TLS_RSA_WITH_AES_128_GCM_SHA256",
      "TLS_RSA_WITH_AES_128_CBC_SHA",
      "SSL_RSA_WITH_3DES_EDE_CBC_SHA");

  // "RSA" in this case refers to the key exchange algorithm,
  // "SHA" refers to the message digest algorithm to provide integrity
  // "NULL" is the encryption algorithm, to disable encryption.
  // TODO: suppot NULL cipher from tcnative
  private final List<String> tlsCipherSuitesNoEncryption = Lists
      .newArrayList("TLS_RSA_WITH_AES_128_GCM_SHA256");

  private Boolean encryption;

  protected GrpcSslConfig(Boolean encryption) {
    this.encryption = encryption;
  }

  public Boolean encryptionEnabled() {
    return encryption;
  }

  public List<String> getTlsCipherSuitesWithEncryption() {
    return tlsCipherSuitesWithEncryption;
  }

  public List<String> getTlsCipherSuitesNoEncryption() {
    return tlsCipherSuitesNoEncryption;
  }

}
